package ListingCustomField::Common;

use strict;

use CustomFields::Field;
use CustomFields::Util qw( get_meta );
use Data::Dumper;

sub display_options {
    my ($cb, $app, $template) = @_;

    my $blog = $app->blog;
    return if !$blog;

    my $mode = $app->param('__mode');
    return if !$mode;

    $mode =~ s/list_(.*)/$1/;
    return if $mode !~ /entry|page|comment|asset/;

    my $plugin = MT->component("ListingCustomField");
    return unless $plugin->get_config_value('use_' . $mode, 'blog:'.$blog->id);

    # display only blog and this_website.
    return if !($blog->parent_id) && $app->param('filter_key') ne 'this_website';

    # アイテムは種別ごとに取得
    if ($mode eq 'asset') {
        $mode = $app->param('filter_key') || return;
    }

    my $terms = { blog_id => $blog->id, obj_type => $mode };
    my $iter = CustomFields::Field->load_iter($terms);

    my $li = '';
    while ( my $field = $iter->() ) {
#        next if $field->type =~ /embed|image|audio|video|file/;
        $li .= '<li><label><input type="checkbox" name="custom_prefs-'.$field->basename.'" id="custom-prefs-'.$field->basename.'" value="1" onclick="displayCustomFields(\'custom-prefs-'.$field->basename.'\'); return true"<mt:if name="custom_prefs-'.$field->basename.'"> checked="checked"</mt:if> class="cb" /> '.$field->name.'</label></li>';
    }

    my $old = <<HTML;
        <div class="actions-bar display-options-actions-bar buttons">
HTML
    $old = quotemeta($old);

    my $new = <<HTML;
$li
        <div class="actions-bar display-options-actions-bar buttons">
HTML
    $$template =~ s/$old/$new/;

    # 既存のリストにblog_idは必要ないが、ここではブログ別のカスタムフィールドを判定する必要があるのでクエリーに追加
    $old = <<HTML;
        <input type="hidden" name="__mode" value="update_list_prefs" />
HTML
    $old = quotemeta($old);

    $new = <<HTML;
        <input type="hidden" name="__mode" value="update_list_prefs" />
        <input type="hidden" name="blog_id" value="<mt:var name="blog_id">" />
HTML
    $$template =~ s/$old/$new/;
}

sub display_options_param {
    my ($cb, $app, $param, $tmpl) = @_;
    my $type = $app->param('__mode');
    $type =~ s/list_(.*)/$1/;

    # アイテムは種別ごとに取得
    if ($type eq 'asset') {
        $type = $app->param('filter_key') || return;
    }

    my $list = $type . $app->param('blog_id');
    my $cookie = $app->cookie_val('cf_list_pref') || '';
    my @list_prefs = split /;/, $cookie;
    foreach my $pref (@list_prefs) {
        my ( $name, $prefs ) = $pref =~ m/^(\w+):(.*)$/;
        next unless $name && $prefs;
        if ( $name eq $list ) {
            my @prefs = split /,/, $prefs;
            foreach (@prefs) {
                my ( $k, $v ) = split /=/;
                $param->{'custom_prefs-'.$k} = $v;
            }
        }
    }
}

1;
