package ListingCustomField::Entry;

use strict;

use CustomFields::Util qw( get_meta );
use Data::Dumper;

sub add_script {
    my ($cb, $app, $template) = @_;

    my $type = $app->param('__mode');
    $type =~ s/list_(.*)/$1/;

    my $plugin = MT->component("ListingCustomField");
    return unless $plugin->get_config_value('use_' . $type, 'blog:'.$app->param('blog_id'));

    my $old = <<HTML;
<mt:setvarblock name="html_head" append="1">
HTML
    $old = quotemeta($old);

    my $terms = { blog_id => $app->param('blog_id'), obj_type => $type };
    my $iter = CustomFields::Field->load_iter($terms);

    # 再構築時にカスタムフィールドのパラメータを取得し判定するサブテンプレート
    # 非表示のフィールドのみcolspanをデクリメントするJavaScriptを出力
    my $script;
    while ( my $field = $iter->() ) {
        my $basename = $field->basename;
$script .= <<EOF;
<mt:if name="custom_prefs-${basename}">
  jQuery('.custom-prefs-${basename}').removeAttr('style');
<mt:else>
  jQuery('.custom-prefs-${basename}').css('display', 'none');
  <mt:if name="view_expanded">
  colspan = jQuery('td.title').attr('colspan');
  colspan--;
  jQuery('td.title').attr('colspan', colspan);
  </mt:if>
</mt:if>
EOF
    }

    my $new = <<HTML;
<mt:setvarblock name="html_head" append="1">
<script type="text/javascript">
/* <![CDATA[ */
function displayCustomFields(class) {
    if (jQuery('#'+class).attr('checked')) {
        jQuery('.'+class).removeAttr('style');
        colspan = jQuery('td.title').attr('colspan');
        colspan++;
        jQuery('td.title').attr('colspan', colspan);
    } else {
        jQuery('.'+class).css('display', 'none');
        colspan = jQuery('td.title').attr('colspan');
        colspan--;
        jQuery('td.title').attr('colspan', colspan);
    }
}
<mt:ignore>詳細の場合のみ</mt:ignore>
jQuery(function() {
$script
});

/* ]]> */
</script>
HTML
    $$template =~ s/$old/$new/;
}

sub add_field {
    my ($cb, $app, $template) = @_;
    my $blog = $app->blog;

    my $type = $app->param('__mode');
    $type =~ s/list_(.*)/$1/;

    my $plugin = MT->component("ListingCustomField");
    return unless $plugin->get_config_value('use_' . $type, 'blog:'.$blog->id);

    # display only blog and this_website.
    return if !($blog->parent_id) && $app->param('filter_key') ne 'this_website';

    my $terms = { blog_id => $blog->id, obj_type => $type };
    my $iter = CustomFields::Field->load_iter($terms);

    my $th = '';
    my $td = '';
    my $counter = 0;
    while ( my $field = $iter->() ) {
#        next if $field->type =~ /embed|image|audio|video|file/;
        $th .= '<th class="custom-prefs-'.$field->basename.'">'. $field->name . '</th>';
        $td .= '<td class="custom-prefs-'.$field->basename.'"><mt:var name="'. $field->basename . '" mteval="1" /></td>';
        $counter++;
    }

    my $old = <<HTML;
                <td class="title"<mt:if name="view_expanded"> colspan="<mt:if name="object_type" eq="page"><mt:if name="blog_view">4<mt:else>5</mt:if><mt:else><mt:if name="blog_view">5<mt:else>6</mt:if></mt:if>"</mt:if>>
HTML
    $old = quotemeta($old);

    my $page_blog = $counter + 5;
    my $page_website = $counter + 6;
    my $entry_blog = $counter + 5;
    my $entry_website = $counter + 6;

    my $new = <<HTML;
                <td class="title"<mt:if name="view_expanded"> colspan="<mt:if name="object_type" eq="page"><mt:if name="blog_view">${page_blog}<mt:else>${page_website}</mt:if><mt:else><mt:if name="blog_view">${entry_blog}<mt:else>${entry_website}</mt:if></mt:if>"</mt:if>>
HTML
    $$template =~ s/$old/$new/;

    my $old = <<HTML;
        </mt:unless>
            </tr>
        </mt:setvarblock>
HTML
    $old = quotemeta($old);

    my $new = <<HTML;
        </mt:unless>
$th
            </tr>
        </mt:setvarblock>
HTML
    $$template =~ s/$old/$new/;

    $old = <<HTML;
            </tr>
    <mt:if __last__>
        </tbody>
HTML
    $old = quotemeta($old);

    $new = <<HTML;
$td
            </tr>
    <mt:if __last__>
        </tbody>
HTML
    $$template =~ s/$old/$new/;
}

sub list_entry {
    my ($cb, $app, $param, $tmpl) = @_;
    my $data = $param->{object_loop};

    # display options
    my $type = $app->param('__mode');
    $type =~ s/list_(.*)/$1/;

    my $plugin = MT->component("ListingCustomField");
    return unless $plugin->get_config_value('use_' . $type, 'blog:'.$app->param('blog_id'));

    foreach my $row (@$data) {
        my $entry = MT::Entry->load($row->{id});
        my $meta = get_meta($entry);
        foreach my $basename (keys %$meta) {
            $row->{$basename} = $meta->{$basename};
        }
    }

    my $list = $type . $app->param('blog_id');

    my $cookie = $app->cookie_val('cf_list_pref') || '';
    my @list_prefs = split /;/, $cookie;
    foreach my $pref (@list_prefs) {
        my ( $name, $prefs ) = $pref =~ m/^(\w+):(.*)$/;
        next unless $name && $prefs;
        if ( $name eq $list ) {
            my @prefs = split /,/, $prefs;
            foreach (@prefs) {
                my ( $k, $v ) = split /=/;
                $param->{'custom_prefs-'.$k} = $v;
            }
        }
    }

}

1;
